@@ -1,7 +1,8 @@
 /*\
- *  dxa v0.1.1 -- symbolic 65xx disassembler
+ *  dxa -- symbolic 65xx disassembler
  *
  *  Copyright (C) 1993, 1994 Marko M\"akel\"a
+ *  Copyright (C) 2019 Cameron Kaiser
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,16 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  Contacting the author:
- *
- *   Via Internet E-mail:
- *      <Marko.Makela@FTP.FUNET.FI>
- *
- *   Via Snail Mail:
- *      Marko M\"akel\"a
- *      Sillitie 10 A
- *      FIN-01480 VANTAA
- *      Finland
 \*/
 
 #define _SCAN_C_
@@ -52,6 +43,8 @@ int ScanSure (ADDR_T scanstart)
   opcodes *instr;
 
   unsigned int size, counter;
+  if (fVerbose)
+    fprintf(stderr, "\n%s: scanning sure section $%04x", prog, scanstart);
 
   for (address = scanstart;; address += size) {
     if (GetMemFlag (address)) /* rest of routine not valid */
@@ -597,6 +590,7 @@ int ScanSpecified (void)
 			(unsigned int)entry->address);
 		return 1;
 	}
+    entry = FindNextEntryType (NULL, ~0, RTN_SURE); // valgrind fart
     DeleteEntry (entry);
   }
 
@@ -825,7 +819,7 @@ void ScanTheRest (void)
       }
 
     if (fVerbose)
-      fprintf (stderr, "\r%s: scanning at %X", prog, address);
+      fprintf (stderr, "\n%s: scanning at $%04x", prog, address);
 
     if (!ScanPotential (address)) {
       while ((entry = FindNextEntryType (NULL, ~RTN_B_TEMPORARY,
